==> chaosmesh-model-6.3.1-sources.jar: io/fabric8/chaosmesh/v1alpha1/DNSChaosListFluent.java <==
package io.fabric8.chaosmesh.v1alpha1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.model.ListMeta;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import java.lang.Long;
import java.util.Iterator;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;

 /**
  * Generated
  */
public interface DNSChaosListFluent<A extends DNSChaosListFluent<A>> extends Fluent<A>{
  public String getApiVersion();
  public A withApiVersion(String apiVersion);
  public Boolean hasApiVersion();
  public A addToItems(Integer index,DNSChaos item);
  public A setToItems(Integer index,DNSChaos item);
  public A addToItems(io.fabric8.chaosmesh.v1alpha1.DNSChaos... items);
  public A addAllToItems(Collection<DNSChaos> items);
  public A removeFromItems(io.fabric8.chaosmesh.v1alpha1.DNSChaos... items);
  public A removeAllFromItems(Collection<DNSChaos> items);
  public A removeMatchingFromItems(Predicate<DNSChaosBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildItems instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<DNSChaos> getItems();
  public List<DNSChaos> buildItems();
  public DNSChaos buildItem(Integer index);
  public DNSChaos buildFirstItem();
  public DNSChaos buildLastItem();
  public DNSChaos buildMatchingItem(Predicate<DNSChaosBuilder> predicate);
  public Boolean hasMatchingItem(Predicate<DNSChaosBuilder> predicate);
  public A withItems(List<DNSChaos> items);
  public A withItems(io.fabric8.chaosmesh.v1alpha1.DNSChaos... items);
  public Boolean hasItems();
  public DNSChaosListFluent.ItemsNested<A> addNewItem();
  public DNSChaosListFluent.ItemsNested<A> addNewItemLike(DNSChaos item);
  public DNSChaosListFluent.ItemsNested<A> setNewItemLike(Integer index,DNSChaos item);
  public DNSChaosListFluent.ItemsNested<A> editItem(Integer index);
  public DNSChaosListFluent.ItemsNested<A> editFirstItem();
  public DNSChaosListFluent.ItemsNested<A> editLastItem();
  public DNSChaosListFluent.ItemsNested<A> editMatchingItem(Predicate<DNSChaosBuilder> predicate);
  public String getKind();
  public A withKind(String kind);
  public Boolean hasKind();
  public ListMeta getMetadata();
  public A withMetadata(ListMeta metadata);
  public Boolean hasMetadata();
  public A withNewMetadata(String _continue,Long remainingItemCount,String resourceVersion,String selfLink);
  public interface ItemsNested<N> extends Nested<N>,DNSChaosFluent<DNSChaosListFluent.ItemsNested<N>>{
    public N and();
    public N endItem();
    
  }
  
}

==> chaosmesh-model-6.7.2-sources.jar: io/fabric8/chaosmesh/v1alpha1/DNSChaosListFluent.java <==
package io.fabric8.chaosmesh.v1alpha1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.model.ListMeta;
import java.util.function.Predicate;
import java.lang.Deprecated;
import java.lang.Long;
import java.util.Iterator;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;

 /**
  * Generated
  */
public interface DNSChaosListFluent<A extends DNSChaosListFluent<A>> extends Fluent<A>{
  public String getApiVersion();
  public A withApiVersion(String apiVersion);
  public Boolean hasApiVersion();
  public A addToItems(int index,DNSChaos item);
  public A setToItems(int index,DNSChaos item);
  public A addToItems(io.fabric8.chaosmesh.v1alpha1.DNSChaos... items);
  public A addAllToItems(Collection<DNSChaos> items);
  public A removeFromItems(io.fabric8.chaosmesh.v1alpha1.DNSChaos... items);
  public A removeAllFromItems(Collection<DNSChaos> items);
  public A removeMatchingFromItems(Predicate<DNSChaosBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildItems instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<DNSChaos> getItems();
  public List<DNSChaos> buildItems();
  public DNSChaos buildItem(int index);
  public DNSChaos buildFirstItem();
  public DNSChaos buildLastItem();
  public DNSChaos buildMatchingItem(Predicate<DNSChaosBuilder> predicate);
  public Boolean hasMatchingItem(Predicate<DNSChaosBuilder> predicate);
  public A withItems(List<DNSChaos> items);
  public A withItems(io.fabric8.chaosmesh.v1alpha1.DNSChaos... items);
  public Boolean hasItems();
  public DNSChaosListFluent.ItemsNested<A> addNewItem();
  public DNSChaosListFluent.ItemsNested<A> addNewItemLike(DNSChaos item);
  public DNSChaosListFluent.ItemsNested<A> setNewItemLike(int index,DNSChaos item);
  public DNSChaosListFluent.ItemsNested<A> editItem(int index);
  public DNSChaosListFluent.ItemsNested<A> editFirstItem();
  public DNSChaosListFluent.ItemsNested<A> editLastItem();
  public DNSChaosListFluent.ItemsNested<A> editMatchingItem(Predicate<DNSChaosBuilder> predicate);
  public String getKind();
  public A withKind(String kind);
  public Boolean hasKind();
  public ListMeta getMetadata();
  public A withMetadata(ListMeta metadata);
  public Boolean hasMetadata();
  public A withNewMetadata(String _continue,Long remainingItemCount,String resourceVersion,String selfLink);
  public interface ItemsNested<N> extends Nested<N>,DNSChaosFluent<DNSChaosListFluent.ItemsNested<N>>{
    public N and();
    public N endItem();
    
  }
  
}
